OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не могу да уписујем у „config“ директоријум!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ово се обично може средити давањем права веб серверу да пише у директоријум са подешавањима",
    "See %s" : "Погледајте %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ово се обично може средити %sдавањем права веб серверу да пише у директоријум са подешавањима%s.",
    "Sample configuration detected" : "Откривен је узорак подешавања",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Откривено је да је узорак подешавања ископиран. Ово може покварити инсталацију и није подржано. Прочитајте документацију пре вршења промена у фајлу config.php",
    "PHP %s or higher is required." : "Потребан је ПХП %s или новији.",
    "PHP with a version lower than %s is required." : "Потребан је ПХП старији од %s.",
    "Following databases are supported: %s" : "Следеће базе података су подржане: %s",
    "The command line tool %s could not be found" : "Није могуће пронаћи командну линију %s",
    "The library %s is not available." : "Библиотека %s није доступна.",
    "Library %s with a version higher than %s is required - available version %s." : "Библиотека %s издања већег од %s је потребна - доступно издање %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Библиотека %s издања нижег од %s је потребна - доступно издање %s.",
    "Following platforms are supported: %s" : "Следеће платформе су подржане: %s",
    "ownCloud %s or higher is required." : "оунКлауд %s или новији је потребан.",
    "ownCloud %s or lower is required." : "оунКлауд %s или старији је потребан.",
    "Unknown filetype" : "Непознат тип фајла",
    "Invalid image" : "Неисправна слика",
    "today" : "данас",
    "yesterday" : "јуче",
    "_%n day ago_::_%n days ago_" : ["пре %n дан","пре %n дана","пре %n дана"],
    "last month" : "прошлог месеца",
    "_%n month ago_::_%n months ago_" : ["пре %n месец","пре %n месеца","пре %n месеци"],
    "last year" : "прошле године",
    "_%n year ago_::_%n years ago_" : ["пре %n годину","пре %n године","пре %n година"],
    "_%n hour ago_::_%n hours ago_" : ["пре %n сат","пре %n сата","пре %n сати"],
    "_%n minute ago_::_%n minutes ago_" : ["пре %n минут","пре %n минута","пре %n минута"],
    "seconds ago" : "пре неколико секунди",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул са ИД %s не постоји. Укључите га у поставкама апликација или контактирајте администратора.",
    "None" : "Ништа",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Empty filename is not allowed" : "Празан назив није дозвољен",
    "Dot files are not allowed" : "Фајлови са почетном тачком нису дозвољени",
    "4-byte characters are not supported in file names" : "4-бајтни знакови нису подржани у називу фајлова",
    "File name is a reserved word" : "Назив фајла је резервисана реч",
    "File name contains at least one invalid character" : "Назив фајла садржи бар један недозвољен знак",
    "File name is too long" : "Назив фајла је предугачак",
    "App directory already exists" : "Директоријум апликација већ постоји",
    "Can't create app folder. Please fix permissions. %s" : "Не могу да креирам фасциклу за апликацију. Исправите дозволе. %s",
    "Archive does not contain a directory named %s" : "Архива не садржи директоријум назива %s",
    "No source specified when installing app" : "Није наведен извор за инсталирање апликације",
    "No href specified when installing app from http" : "Није наведена адреса за инсталирање апликације преко http",
    "No path specified when installing app from local file" : "Није наведена путања за инсталирање апликације са локалног фајла",
    "Archives of type %s are not supported" : "%s архиве нису подржане",
    "Failed to open archive when installing app" : "Неуспешно отварање архиве приликом инсталације апликације",
    "App does not provide an info.xml file" : "Апликација не поседује info.xml фајл",
    "App can't be installed because of not allowed code in the App" : "Апликације не може бити инсталирана због недозвољеног кода у апликацији",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Апликације не може бити инсталирана јер није компатибилна са овом верзијом оунКлауда",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Апликација се не може инсталирати јер садржи ознаку <shipped>тачно</shipped> која није дозвољена за неиспоручене апликације",
    "Apps" : "Апликације",
    "General" : "Опште",
    "Storage" : "Складиште",
    "Security" : "Безбедност",
    "Encryption" : "Шифровање",
    "Sharing" : "Дељење",
    "Search" : "Тражи",
    "Updates" : "Ажурирања",
    "%s enter the database username." : "%s унеси корисничко име базе података.",
    "%s enter the database name." : "%s унеси име базе података.",
    "%s you may not use dots in the database name" : "%s не можете користити тачке у имену базе података",
    "Oracle connection could not be established" : "Веза са базом података Oracle не може бити успостављена",
    "Oracle username and/or password not valid" : "Oracle корисничко име и/или лозинка нису исправни",
    "DB Error: \"%s\"" : "Грешка базе података: \"%s\"",
    "Offending command was: \"%s\"" : "Неисправна команда је: „%s“",
    "You need to enter either an existing account or the administrator." : "Потребно је да унесете или постојећи налог или администраторски.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Неисправна команда је: „%s“, назив: %s, лозинка: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничко име и/или лозинка нису исправни",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Мек ОС Икс није подржан и %s неће радити исправно на овој платформи. Користите га на сопствени ризик!",
    "For the best results, please consider using a GNU/Linux server instead." : "За најбоље резултате, размотрите употребу ГНУ/Линукс сервера.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Изгледа да %s ради у 32-битном ПХП окружењу а open_basedir је подешен у php.ini фајлу. То може довести до проблема са фајловима већим од 4 GB те стога није препоручљиво.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Уклоните open_basedir поставку из php.ini фајла или пређите на 64-битни ПХП.",
    "Set an admin username." : "Поставите име за администратора.",
    "Set an admin password." : "Поставите лозинку за администратора.",
    "Can't create or write into the data directory %s" : "Не могу креирати или уписивати у директоријум података %s",
    "Invalid Federated Cloud ID" : "Неисправан ИД Здруженог облака",
    "%s shared »%s« with you" : "%s подели „%s“ са вама",
    "%s via %s" : "%s путем %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Дељење %s није успело зато што поздина не дозвољава дељење од типа %i",
    "Sharing %s failed, because the file does not exist" : "Дељење %s није успело зато што фајл не постоји",
    "You are not allowed to share %s" : "Није вам дозвољено да делите %s",
    "Sharing %s failed, because the user %s does not exist" : "Дељење %s није успело зато што не постоји корисник %s",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Дељење %s није успело зато што корисник %s није члан групе која је %s члан ",
    "Sharing %s failed, because this item is already shared with %s" : "Дељење %s није успело зато што се ова ставка већ дели са %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Дељење %s није успело зато што се ова ставка већ дели са корисником %s",
    "Sharing %s failed, because the group %s does not exist" : "Дељење %s није успело зато што непостоји група %s",
    "Sharing %s failed, because %s is not a member of the group %s" : "Дељење %s није успело зато што %s није члан групе %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Морате да обезбедите лозинку за креирање јавне везе, дозвољене су само заштићене везе",
    "Sharing %s failed, because sharing with links is not allowed" : "Дељење %s није успело зато што дељење са везама није дозвољено",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Дељење %s није успело, није могуће пронаћи %s, можда сервер тренутно није доступан.",
    "Share type %s is not valid for %s" : "Тип фајла за дељење %s није исправан за %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Постављање дозвола за %s није успело зато што дозволе превазилазе дозволе гарантоване за %s",
    "Setting permissions for %s failed, because the item was not found" : "Постављање дозвола за %s није успело зато што ставка није пронађена",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Не могу поставити датум трајања. Дељења не могу истицати касније од %s пошто су активирана",
    "Cannot set expiration date. Expiration date is in the past" : "Не могу поставити датум трајања. Датум трајања употребе је у прошлости",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Не могу обрисати датум трајања. Дељења су у обавези да имају ограничен датум трајања.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Позадина дељења %s мора користити корисничко окружење OCP\\Share_Backend",
    "Sharing backend %s not found" : "Позадина за дељење %s није пронађена",
    "Sharing backend for %s not found" : "Позадина за дељење за %s није пронађена",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Дељење %s није успело зато што дозволе превазилазе дозволе гарантоване за %s",
    "Sharing %s failed, because resharing is not allowed" : "Дељење %s није успело зато што даље дељење није дозвољено",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Дељење %s није успело зато што позадина дељења за %s није могла да нађе извор",
    "Sharing %s failed, because the file could not be found in the file cache" : "Дељење %s није успело зато што фајл није нађен у кешу фајлова",
    "Could not find category \"%s\"" : "Не могу да пронађем категорију „%s“.",
    "A valid username must be provided" : "Морате унети исправно корисничко име",
    "A valid password must be provided" : "Морате унети исправну лозинку",
    "The username is already being used" : "Корисничко име се већ користи",
    "Help" : "Помоћ",
    "Settings" : "Поставке",
    "Users" : "Корисници",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Апликација „%s“ не може бити инсталирана јер следеће зависности нису испуњене: %s",
    "web services under your control" : "веб сервиси под вашом контролом",
    "File is currently busy, please try again later" : "Фајл је тренутно заузет, покушајте поново касније",
    "Can't read file" : "Не могу да читам фајл",
    "Application is not enabled" : "Апликација није укључена",
    "Authentication error" : "Грешка аутентификације",
    "Token expired. Please reload page." : "Жетон је истекао. Поново учитајте страницу.",
    "Unknown user" : "Непознат корисник",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема драјвера базе података (скулајт, мајскул или постгрескул).",
    "Cannot write into \"config\" directory" : "Не могу уписивати у директоријуму „config“",
    "Cannot write into \"apps\" directory" : "Не могу уписивати у директоријуму „apps“",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ово се обично може поправити %sgдавањем права уписа веб серверу директоријум%s апликација или искуључивањем продавнице апликација у датотеци config file.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Дозволе се обично могу поправити  %sдавањем права уписивања веб серверу основни директоријум%s.",
    "Setting locale to %s failed" : "Постављање локалитета на %s није успело",
    "Please install one of these locales on your system and restart your webserver." : "Инсталирајте неки од ових локалитета на ваш систем и поново покрените веб сервер.",
    "Please ask your server administrator to install the module." : "Замолите администратора вашег сервера да инсталира тај модул.",
    "PHP module %s not installed." : "ПХП модул %s није инсталиран.",
    "PHP setting \"%s\" is not set to \"%s\"." : "ПХП поставка „%s“ није постављена на „%s“.",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Подешавање ове поставке у php.ini фајлу ће омогућити да оунКлауд поново ради",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload је постављено на „%s“ уместо на очекивану вредност „0“",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Да би решили овај проблем поставите <code>mbstring.func_overload</code> на <code>0</code> у фајлу php.ini",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "ПХП је очигледно подешен да скида уметнуте doc блокове. То ће учинити неколико кључних апликација недоступним.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ово је вероватно изазвано кешом или акцелератором као што су ЗендОПкеш или еАкцелератор.",
    "PHP modules have been installed, but they are still listed as missing?" : "ПХП модули су инсталирани али се и даље воде као недостајући?",
    "Please ask your server administrator to restart the web server." : "Замолите вашег администратора сервера да поново покрене веб сервер.",
    "PostgreSQL >= 9 required" : "Захтеван је ПостгреСкул >= 9",
    "Please upgrade your database version" : "Надоградите ваше издање базе",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Промените дозволе у 0770 како директоријуми не би могли бити излистани од стране других корисника.",
    "Check the value of \"datadirectory\" in your configuration" : "Проверите податак за \"datadirectory\" у вашој конфигурацији",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Проверите да ли директоријум података садржи фајл „.ocdata“ у свом основном директоријуму.",
    "Could not obtain lock type %d on \"%s\"." : "Не могу да остварим закључаност %d за „%s“.",
    "Imprint" : "Жиг",
    "__language_name__" : "Српски"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
